bayespy.inference.vmp.nodes.stochastic.Stochastic.load
======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.load